TinyXml: TiXmlElement Class Reference

# TiXmlElement Class Reference

The element is a container class. More...

`#include <tinyxml.h>`

Inheritance diagram for TiXmlElement:

List of all members.

## Public Member Functions
| TiXmlElement (const char *in_value)
| Construct an element.
| TiXmlElement (const std::string &_value)
| std::string constructor.
const char * | Attribute (const char *name) const
| Given an attribute name, Attribute() returns the value for the attribute of that name, or null if none exists.
const char * | Attribute (const char *name, int *i) const
| Given an attribute name, Attribute() returns the value for the attribute of that name, or null if none exists.
const char * | Attribute (const char *name, double *d) const
| Given an attribute name, Attribute() returns the value for the attribute of that name, or null if none exists.
int | QueryIntAttribute (const char *name, int *_value) const
| QueryIntAttribute examines the attribute - it is an alternative to the Attribute() method with richer error checking.
int | QueryUnsignedAttribute (const char *name, unsigned *_value) const
| QueryUnsignedAttribute examines the attribute - see QueryIntAttribute().
int | QueryBoolAttribute (const char *name, bool *_value) const
| QueryBoolAttribute examines the attribute - see QueryIntAttribute().
int | QueryDoubleAttribute (const char *name, double *_value) const
| QueryDoubleAttribute examines the attribute - see QueryIntAttribute().
int | QueryFloatAttribute (const char *name, float *_value) const
| QueryFloatAttribute examines the attribute - see QueryIntAttribute().
int | QueryStringAttribute (const char *name, std::string *_value) const
| QueryStringAttribute examines the attribute - see QueryIntAttribute().
template<typename T >
int | QueryValueAttribute (const std::string &name, T *outValue) const
| Template form of the attribute query which will try to read the attribute into the specified type.
void | SetAttribute (const char *name, const char *_value)
| Sets an attribute of name to a given value.
void | SetAttribute (const std::string &name, const std::string &_value)
void | SetAttribute (const std::string &name, int _value)
| STL std::string form.
void | SetAttribute (const char *name, int value)
| Sets an attribute of name to a given value.
void | SetDoubleAttribute (const char *name, double value)
| Sets an attribute of name to a given value.
void | RemoveAttribute (const char *name)
| Deletes an attribute with the given name.
void | RemoveAttribute (const std::string &name)
| STL std::string form.
const TiXmlAttribute * | FirstAttribute () const
| Access the first attribute in this element.
const TiXmlAttribute * | LastAttribute () const
| Access the last attribute in this element.
const char * | GetText () const
| Convenience function for easy access to the text inside an element.
virtual TiXmlNode * | Clone () const
| Creates a new Element and returns it - the returned element is a copy.
virtual void | Print (FILE *cfile, int depth) const
| All TinyXml classes can print themselves to a filestream or the string class (TiXmlString in non-STL mode, std::string in STL mode.
virtual const TiXmlElement * | ToElement () const
| Cast to a more defined type. Will return null not of the requested type.
virtual TiXmlElement * | ToElement ()
| Cast to a more defined type. Will return null not of the requested type.
virtual bool | Accept (TiXmlVisitor *visitor) const
| Walk the XML tree visiting this node and all of its children.

## Detailed Description

The element is a container class.

It has a value, the element name, and can contain other elements, text, comments, and unknowns. Elements also contain an arbitrary number of attributes.

## Member Function Documentation

const char* TiXmlElement::Attribute | ( | const char * | name,
|  | double * | d |
| ) |  |  | const

Given an attribute name, Attribute() returns the value for the attribute of that name, or null if none exists.

If the attribute exists and can be converted to an double, the double value will be put in the return 'd', if 'd' is non-null.

const char* TiXmlElement::Attribute | ( | const char * | name,
|  | int * | i |
| ) |  |  | const

Given an attribute name, Attribute() returns the value for the attribute of that name, or null if none exists.

If the attribute exists and can be converted to an integer, the integer value will be put in the return 'i', if 'i' is non-null.

const char* TiXmlElement::GetText | ( |  | ) | const

Convenience function for easy access to the text inside an element.

Although easy and concise, GetText() is limited compared to getting the TiXmlText child and accessing it directly.

If the first child of 'this' is a TiXmlText, the GetText() returns the character string of the Text node, else null is returned.

This is a convenient method for getting the text of simple contained text:

    		<foo>This is text</foo>
    		const char* str = fooElement->GetText();

'str' will be a pointer to "This is text".

Note that this function can be misleading. If the element foo was created from this XML:

    		<foo><b>This is text</b></foo>

then the value of str would be null. The first child node isn't a text node, it is another element. From this XML:

    		<foo>This is <b>text</b></foo>

GetText() will return "This is ".

WARNING: GetText() accesses a child node - don't become confused with the similarly named TiXmlHandle::Text() and TiXmlNode::ToText() which are safe type casts on the referenced node.

virtual void TiXmlElement::Print | ( | FILE * | cfile,
|  | int | depth |
| ) |  |  | const`[virtual]`

All TinyXml classes can print themselves to a filestream or the string class (TiXmlString in non-STL mode, std::string in STL mode.

) Either or both cfile and str can be null.

This is a formatted print, and will insert tabs and newlines.

(For an unformatted stream, use the << operator.)

Implements TiXmlBase.

int TiXmlElement::QueryBoolAttribute | ( | const char * | name,
|  | bool * | _value |
| ) |  |  | const

QueryBoolAttribute examines the attribute - see QueryIntAttribute().

Note that '1', 'true', or 'yes' are considered true, while '0', 'false' and 'no' are considered false.

int TiXmlElement::QueryIntAttribute | ( | const char * | name,
|  | int * | _value |
| ) |  |  | const

QueryIntAttribute examines the attribute - it is an alternative to the Attribute() method with richer error checking.

If the attribute is an integer, it is stored in 'value' and the call returns TIXML_SUCCESS. If it is not an integer, it returns TIXML_WRONG_TYPE. If the attribute does not exist, then TIXML_NO_ATTRIBUTE is returned.

template<typename T >

int TiXmlElement::QueryValueAttribute | ( | const std::string & | name,
|  | T * | outValue |
| ) |  |  | const`[inline]`

Template form of the attribute query which will try to read the attribute into the specified type.

Very easy, very powerful, but be careful to make sure to call this with the correct type.

NOTE: This method doesn't work correctly for 'string' types that contain spaces.

Returns:
  TIXML_SUCCESS, TIXML_WRONG_TYPE, or TIXML_NO_ATTRIBUTE

References TiXmlAttribute::ValueStr().

void TiXmlElement::SetAttribute | ( | const char * | name,
|  | int | value |
| ) |  |  |

Sets an attribute of name to a given value.

The attribute will be created if it does not exist, or changed if it does.

void TiXmlElement::SetAttribute | ( | const std::string & | name,
|  | const std::string & | _value |
| ) |  |  |

STL std::string form.

void TiXmlElement::SetAttribute | ( | const char * | name,
|  | const char * | _value |
| ) |  |  |

Sets an attribute of name to a given value.

The attribute will be created if it does not exist, or changed if it does.

void TiXmlElement::SetDoubleAttribute | ( | const char * | name,
|  | double | value |
| ) |  |  |

Sets an attribute of name to a given value.

The attribute will be created if it does not exist, or changed if it does.

The documentation for this class was generated from the following file:

- tinyxml.h